"use strict";
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var document_manager_exports = {};
__export(document_manager_exports, {
  DocumentManager: () => DocumentManager
});
module.exports = __toCommonJS(document_manager_exports);
var import_rxjs = require("rxjs");
class DocumentManager {
  constructor(factory, reader) {
    this.factory = factory;
    this.reader = reader;
    this.documents = /* @__PURE__ */ new Map();
    this.activeDocuments = /* @__PURE__ */ new Set();
    this.createdSubject = new import_rxjs.Subject();
    this.closedSubject = new import_rxjs.Subject();
    this.openedSubject = new import_rxjs.Subject();
    this.deletedSubject = new import_rxjs.Subject();
    this.changedSubject = new import_rxjs.Subject();
  }
  get created$() {
    return this.createdSubject.asObservable();
  }
  get closed$() {
    return this.closedSubject.asObservable();
  }
  get opened$() {
    return this.openedSubject.asObservable();
  }
  get deleted$() {
    return this.deletedSubject.asObservable();
  }
  get changed$() {
    return this.changedSubject.asObservable();
  }
  add(doc) {
    this.documents.set(doc.uri, doc);
    this.activeDocuments.add(doc.uri);
  }
  async get(uri) {
    let doc = this.documents.get(uri);
    if (doc == null) {
      doc = await this.reload(uri);
    }
    return doc;
  }
  async all() {
    const docs = Array.from(this.documents.values());
    if (this.reader != null) {
      for (const id of this.reader.keys()) {
        if (this.documents.has(id)) continue;
        const doc = await this.get(id);
        if (doc != null) {
          docs.push(doc);
        }
      }
    }
    return docs;
  }
  async active() {
    const docs = [];
    for (const uri of this.activeDocuments) {
      const doc = await this.get(uri);
      if (doc != null) {
        docs.push(doc);
      }
    }
    return docs;
  }
  async fireCreated(uri) {
    const doc = await this.get(uri);
    if (doc != null) {
      this.createdSubject.next({ document: doc });
    }
  }
  fireClosed(uri) {
    this.documents.delete(uri);
    this.activeDocuments.delete(uri);
    this.closedSubject.next({ uri });
    return Promise.resolve();
  }
  fireOpened(uri, format, version, content) {
    const doc = this.factory.create(uri, format, version, content);
    this.documents.set(uri, doc);
    this.activeDocuments.add(uri);
    this.openedSubject.next({ document: doc });
    return Promise.resolve();
  }
  fireDeleted(uri) {
    this.documents.delete(uri);
    this.deletedSubject.next({ uri });
    return Promise.resolve();
  }
  async fireChanged(uri, changes, version) {
    let doc = void 0;
    if (changes == null) {
      doc = await this.reload(uri);
    } else {
      doc = await this.get(uri);
      if (doc != null) {
        doc = this.factory.update(doc, changes, version ?? 0);
        this.documents.set(uri, doc);
      }
    }
    if (doc != null) {
      this.changedSubject.next({ document: doc });
    }
  }
  async reload(uri) {
    const data = await this.reader?.read(uri);
    const doc = data == null ? void 0 : this.factory.create(uri, data.format, data.version, data.content);
    if (doc != null) {
      this.documents.set(uri, doc);
    }
    return doc;
  }
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  DocumentManager
});
