import { Observable } from 'rxjs';
import { Document } from './document.js';
import { DocumentFactory, DocumentChange } from './document-factory.js';
import { DocumentReader } from './document-reader.js';
import '../common/range.js';
import '../common/position.js';

interface DocumentCreated<T extends Document> {
    document: T;
}
interface DocumentClosed {
    uri: string;
}
interface DocumentOpened<T extends Document> {
    document: T;
}
interface DocumentDeleted {
    uri: string;
}
interface DocumentChanged<T extends Document> {
    document: T;
}
declare class DocumentManager<T extends Document> {
    private readonly factory;
    private readonly reader?;
    private readonly documents;
    private readonly activeDocuments;
    private readonly createdSubject;
    private readonly closedSubject;
    private readonly openedSubject;
    private readonly deletedSubject;
    private readonly changedSubject;
    constructor(factory: DocumentFactory<T>, reader?: DocumentReader | undefined);
    get created$(): Observable<DocumentCreated<T>>;
    get closed$(): Observable<DocumentClosed>;
    get opened$(): Observable<DocumentOpened<T>>;
    get deleted$(): Observable<DocumentDeleted>;
    get changed$(): Observable<DocumentChanged<T>>;
    add(doc: T): void;
    get(uri: string): Promise<T | undefined>;
    all(): Promise<T[]>;
    active(): Promise<T[]>;
    fireCreated(uri: string): Promise<void>;
    fireClosed(uri: string): Promise<void>;
    fireOpened(uri: string, format: string, version: number, content: string): Promise<void>;
    fireDeleted(uri: string): Promise<void>;
    fireChanged(uri: string, changes?: readonly DocumentChange[], version?: number): Promise<void>;
    private reload;
}

export { type DocumentChanged, type DocumentClosed, type DocumentCreated, type DocumentDeleted, DocumentManager, type DocumentOpened };
