import { Position } from '../common/position.js';
import { Range } from '../common/range.js';
import { ScriptureNode, ScriptureNodeType, ScriptureDocument } from './scripture-document.js';
import './document.js';
import './text-document.js';
import './document-factory.js';

declare abstract class ScriptureContainer implements ScriptureNode {
    private _parent?;
    private readonly _children;
    readonly isLeaf = false;
    range: Range;
    constructor(children?: ScriptureNode[]);
    abstract readonly type: ScriptureNodeType;
    get document(): ScriptureDocument | undefined;
    get parent(): ScriptureNode | undefined;
    get children(): readonly ScriptureNode[];
    updateParent(parent: ScriptureNode | undefined): void;
    remove(): void;
    getText(): string;
    findNodes(filter?: ScriptureNodeType | ((node: ScriptureNode) => boolean) | ScriptureNodeType[]): IterableIterator<ScriptureNode>;
    positionAt(offset: number): Position;
    appendChild(child: ScriptureNode): void;
    insertChild(index: number, child: ScriptureNode): void;
    removeChild(child: ScriptureNode): void;
    spliceChildren(start: number, deleteCount: number, ...items: ScriptureNode[]): void;
    clearChildren(): void;
}

export { ScriptureContainer };
