import { Position } from '../common/position.js';
import { Range } from '../common/range.js';
import { Document } from './document.js';
import { TextDocument } from './text-document.js';
import './document-factory.js';

declare class ScriptureDocument extends TextDocument implements Document, ScriptureNode {
    readonly uri: string;
    private readonly _children;
    readonly parent: undefined;
    readonly isLeaf = false;
    readonly type = ScriptureNodeType.Document;
    readonly document: this;
    range: Range;
    constructor(uri: string, version: number, content: string, children?: ScriptureNode[]);
    get children(): readonly ScriptureNode[];
    updateParent(_parent: ScriptureNode | undefined): void;
    remove(): void;
    findNodes(filter?: ScriptureNodeType | ((node: ScriptureNode) => boolean) | ScriptureNodeType[]): IterableIterator<ScriptureNode>;
    appendChild(child: ScriptureNode): void;
    insertChild(index: number, child: ScriptureNode): void;
    removeChild(child: ScriptureNode): void;
    spliceChildren(start: number, deleteCount: number, ...items: ScriptureNode[]): void;
    clearChildren(): void;
}
declare enum ScriptureNodeType {
    Document = 0,
    Book = 1,
    Paragraph = 2,
    Chapter = 3,
    Verse = 4,
    Milestone = 5,
    Text = 6,
    CharacterStyle = 7,
    Note = 8,
    Table = 9,
    Row = 10,
    Cell = 11,
    Ref = 12,
    OptBreak = 13,
    Sidebar = 14
}
interface ScriptureNode {
    readonly type: ScriptureNodeType;
    readonly document: ScriptureDocument | undefined;
    readonly parent: ScriptureNode | undefined;
    readonly children: readonly ScriptureNode[];
    range: Range;
    readonly isLeaf: boolean;
    updateParent(parent: ScriptureNode | undefined): void;
    remove(): void;
    getText(): string;
    findNodes(filter?: ScriptureNodeType | ((node: ScriptureNode) => boolean)): IterableIterator<ScriptureNode>;
    positionAt(offset: number): Position;
    appendChild(child: ScriptureNode): void;
    insertChild(index: number, child: ScriptureNode): void;
    removeChild(child: ScriptureNode): void;
    spliceChildren(start: number, deleteCount: number, ...items: ScriptureNode[]): void;
    clearChildren(): void;
}
declare function findNodes(node: ScriptureNode, filter?: ScriptureNodeType | ((node: ScriptureNode) => boolean) | ScriptureNodeType[]): IterableIterator<ScriptureNode>;

export { ScriptureDocument, type ScriptureNode, ScriptureNodeType, findNodes };
