import { TextDocument } from './text-document.js';
class ScriptureDocument extends TextDocument {
  constructor(uri, version, content, children) {
    super(uri, version, content);
    this.uri = uri;
    this._children = [];
    this.parent = void 0;
    this.isLeaf = false;
    this.type = 0 /* Document */;
    this.document = this;
    this.range = { start: { line: 0, character: 0 }, end: { line: 0, character: 0 } };
    if (children != null) {
      for (const child of children) {
        this.appendChild(child);
      }
    }
  }
  get children() {
    return this._children;
  }
  updateParent(_parent) {
    throw new Error("The method is not supported.");
  }
  remove() {
    throw new Error("The method is not supported.");
  }
  findNodes(filter) {
    return findNodes(this, filter);
  }
  appendChild(child) {
    this._children.push(child);
    child.updateParent(this);
  }
  insertChild(index, child) {
    this._children.splice(index, 0, child);
    child.updateParent(this);
  }
  removeChild(child) {
    if (child.parent !== this) {
      throw new Error("This node does not contain the specified child.");
    }
    const index = this._children.indexOf(child);
    if (index === -1) {
      throw new Error("This node does not contain the specified child.");
    }
    this._children.splice(index, 1);
    child.updateParent(void 0);
  }
  spliceChildren(start, deleteCount, ...items) {
    const removed = this._children.splice(start, deleteCount, ...items);
    for (const child of removed) {
      child.updateParent(void 0);
    }
    for (const child of items) {
      child.updateParent(this);
    }
  }
  clearChildren() {
    this._children.length = 0;
  }
}
var ScriptureNodeType = /* @__PURE__ */ ((ScriptureNodeType2) => {
  ScriptureNodeType2[ScriptureNodeType2["Document"] = 0] = "Document";
  ScriptureNodeType2[ScriptureNodeType2["Book"] = 1] = "Book";
  ScriptureNodeType2[ScriptureNodeType2["Paragraph"] = 2] = "Paragraph";
  ScriptureNodeType2[ScriptureNodeType2["Chapter"] = 3] = "Chapter";
  ScriptureNodeType2[ScriptureNodeType2["Verse"] = 4] = "Verse";
  ScriptureNodeType2[ScriptureNodeType2["Milestone"] = 5] = "Milestone";
  ScriptureNodeType2[ScriptureNodeType2["Text"] = 6] = "Text";
  ScriptureNodeType2[ScriptureNodeType2["CharacterStyle"] = 7] = "CharacterStyle";
  ScriptureNodeType2[ScriptureNodeType2["Note"] = 8] = "Note";
  ScriptureNodeType2[ScriptureNodeType2["Table"] = 9] = "Table";
  ScriptureNodeType2[ScriptureNodeType2["Row"] = 10] = "Row";
  ScriptureNodeType2[ScriptureNodeType2["Cell"] = 11] = "Cell";
  ScriptureNodeType2[ScriptureNodeType2["Ref"] = 12] = "Ref";
  ScriptureNodeType2[ScriptureNodeType2["OptBreak"] = 13] = "OptBreak";
  ScriptureNodeType2[ScriptureNodeType2["Sidebar"] = 14] = "Sidebar";
  return ScriptureNodeType2;
})(ScriptureNodeType || {});
function* findNodes(node, filter) {
  for (const child of node.children) {
    if (filter == null || Array.isArray(filter) && filter.includes(child.type) || typeof filter === "function" && filter(child) || child.type === filter) {
      yield child;
    }
    yield* findNodes(child, filter);
  }
}
export {
  ScriptureDocument,
  ScriptureNodeType,
  findNodes
};
