import { Position } from '../common/position.js';
import { Range } from '../common/range.js';
import { ScriptureNode, ScriptureNodeType, ScriptureDocument } from './scripture-document.js';
import './document.js';
import './text-document.js';
import './document-factory.js';

declare abstract class ScriptureLeaf implements ScriptureNode {
    range: Range;
    private _parent?;
    readonly children: readonly ScriptureNode[];
    readonly isLeaf = true;
    constructor(range?: Range);
    abstract readonly type: ScriptureNodeType;
    get document(): ScriptureDocument | undefined;
    get parent(): ScriptureNode | undefined;
    updateParent(parent: ScriptureNode | undefined): void;
    remove(): void;
    getText(): string;
    findNodes(_filter?: ScriptureNodeType | ((node: ScriptureNode) => boolean) | ScriptureNodeType[]): IterableIterator<ScriptureNode>;
    positionAt(offset: number): Position;
    appendChild(_child: ScriptureNode): void;
    insertChild(_index: number, _child: ScriptureNode): void;
    removeChild(_child: ScriptureNode): void;
    spliceChildren(_start: number, _deleteCount: number, ..._items: ScriptureNode[]): void;
    clearChildren(): void;
}

export { ScriptureLeaf };
