import { Localizer } from './localizer.js';
import { Observable } from 'rxjs';
import { Position } from '../common/position.js';
import { TextEdit } from '../common/text-edit.js';
import { Diagnostic } from '../diagnostic/diagnostic.js';
import { DiagnosticFix } from '../diagnostic/diagnostic-fix.js';
import { DiagnosticProvider, DiagnosticsChanged } from '../diagnostic/diagnostic-provider.js';
import { OnTypeFormattingProvider } from '../formatting/on-type-formatting-provider.js';
import '../common/range.js';

interface WorkspaceConfig {
    localizer: Localizer;
    diagnosticProviders?: DiagnosticProvider[];
    onTypeFormattingProviders?: OnTypeFormattingProvider[];
}
declare class Workspace {
    private readonly localizer;
    private readonly diagnosticProviders;
    private readonly onTypeFormattingProviders;
    private readonly lastDiagnosticChangedEvents;
    readonly diagnosticsChanged$: Observable<DiagnosticsChanged>;
    constructor(config: WorkspaceConfig);
    init(): Promise<void>;
    changeLanguage(language: string): Promise<void>;
    getDiagnostics(uri: string): Promise<Diagnostic[]>;
    getDiagnosticFixes(uri: string, diagnostic: Diagnostic): Promise<DiagnosticFix[]>;
    getOnTypeTriggerCharacters(): string[];
    getOnTypeEdits(uri: string, position: Position, ch: string): Promise<TextEdit[] | undefined>;
    private updateCombinedDiagnosticChangedEvent;
    private getCombinedDiagnosticChangedEvent;
}

export { Workspace, type WorkspaceConfig };
